@@ -1,13 +1,14 @@
 from ceph_deploy.util import pkg_managers, templates
 from ceph_deploy.lib import remoto
+from ceph_deploy.hosts.util import install_yum_priorities
 
 
 def rpm_dist(distro):
-    # start using the el7 prefix now that rhel7 exists.
-    if distro.normalized_name == 'redhat' and distro.release.startswith('7'):
-        return 'el7'
+    if distro.normalized_name in ['redhat', 'centos', 'scientific'] and distro.normalized_release.int_major >= 6:
+        return 'el' + distro.normalized_release.major
     return 'el6'
 
+
 def repository_url_part(distro):
     """
     Historically everything CentOS, RHEL, and Scientific has been mapped to
@@ -24,11 +25,12 @@ def repository_url_part(distro):
         ('Red Hat Enterprise Linux Server', '7.0', 'Maipo')
 
     """
-    if distro.normalized_name == 'redhat':
-        if distro.release.startswith('6'):
-            return 'rhel6'
-        elif distro.release.startswith('7'):
-            return 'rhel7'
+    if distro.normalized_release.int_major >= 6:
+        if distro.normalized_name == 'redhat':
+            return 'rhel' + distro.normalized_release.major
+        if distro.normalized_name in ['centos', 'scientific']:
+            return 'el' + distro.normalized_release.major
+
     return 'el6'
 
 
@@ -54,38 +56,47 @@ def install(distro, version_kind, version, adjust_repos):
         key = 'autobuild'
 
     if adjust_repos:
-        remoto.process.run(
-            distro.conn,
-            [
-                'rpm',
-                '--import',
-                "https://ceph.com/git/?p=ceph.git;a=blob_plain;f=keys/{key}.asc".format(key=key)
-            ]
-        )
+        if version_kind != 'dev':
+            remoto.process.run(
+                distro.conn,
+                [
+                    'rpm',
+                    '--import',
+                    "https://ceph.com/git/?p=ceph.git;a=blob_plain;f=keys/{key}.asc".format(key=key)
+                ]
+            )
 
-        if version_kind == 'stable':
-            url = 'http://ceph.com/rpm-{version}/{repo}/'.format(
-                version=version,
-                repo=repo_part,
-                )
-        elif version_kind == 'testing':
-            url = 'http://ceph.com/rpm-testing/{repo}/'.format(repo=repo_part)
-        elif version_kind == 'dev':
-            url = 'http://gitbuilder.ceph.com/ceph-rpm-centos{release}-{machine}-basic/ref/{version}/'.format(
-                release=release.split(".",1)[0],
-                machine=machine,
-                version=version,
-                )
+            if version_kind == 'stable':
+                url = 'http://ceph.com/rpm-{version}/{repo}/'.format(
+                    version=version,
+                    repo=repo_part,
+                    )
+            elif version_kind == 'testing':
+                url = 'http://ceph.com/rpm-testing/{repo}/'.format(repo=repo_part)
 
-        remoto.process.run(
-            distro.conn,
-            [
-                'rpm',
-                '-Uvh',
-                '--replacepkgs',
-                '{url}noarch/ceph-release-1-0.{dist}.noarch.rpm'.format(url=url, dist=dist),
-            ],
-        )
+            remoto.process.run(
+                distro.conn,
+                [
+                    'rpm',
+                    '-Uvh',
+                    '--replacepkgs',
+                    '{url}noarch/ceph-release-1-0.{dist}.noarch.rpm'.format(url=url, dist=dist),
+                ],
+            )
+
+        if version_kind == 'dev':
+            logger.info('skipping install of ceph-release package')
+            logger.info('repo file will be created manually')
+            mirror_install(
+                distro,
+                'http://gitbuilder.ceph.com/ceph-rpm-centos{release}-{machine}-basic/ref/{version}/'.format(
+                    release=release.split(".", 1)[0],
+                    machine=machine,
+                    version=version),
+                "https://ceph.com/git/?p=ceph.git;a=blob_plain;f=keys/{key}.asc".format(key=key),
+                adjust_repos=True,
+                extra_installs=False
+            )
 
         # set the right priority
         logger.warning('ensuring that /etc/yum.repos.d/ceph.repo contains a high priority')
@@ -136,35 +147,7 @@ def install_epel(distro):
             )
 
 
-def install_yum_priorities(distro):
-    """
-    EPEL started packaging Ceph so we need to make sure that the ceph.repo we
-    install has a higher priority than the EPEL repo so that when installing
-    Ceph it will come from the repo file we create.
-
-    The name of the package changed back and forth (!) since CentOS 4:
-
-    From the CentOS wiki::
-
-        Note: This plugin has carried at least two differing names over time.
-        It is named yum-priorities on CentOS-5 but was named
-        yum-plugin-priorities on CentOS-4. CentOS-6 has reverted to
-        yum-plugin-priorities.
-
-    """
-    if distro.normalized_name == 'centos':
-        if distro.release[0] == '6':
-            package_name = 'yum-plugin-priorities'
-        else:
-            package_name = 'yum-priorities'
-
-        pkg_managers.yum(
-            distro.conn,
-            package_name,
-        )
-
-
-def mirror_install(distro, repo_url, gpg_url, adjust_repos):
+def mirror_install(distro, repo_url, gpg_url, adjust_repos, extra_installs=True):
     repo_url = repo_url.strip('/')  # Remove trailing slashes
     gpg_url_path = gpg_url.split('file://')[-1]  # Remove file if present
 
@@ -187,10 +170,11 @@ def mirror_install(distro, repo_url, gpg_url, adjust_repos):
 
         distro.conn.remote_module.write_yum_repo(ceph_repo_content)
 
-    # Before any install, make sure we have `wget`
-    pkg_managers.yum(distro.conn, 'wget')
+    if extra_installs:
+        # Before any install, make sure we have `wget`
+        pkg_managers.yum(distro.conn, 'wget')
 
-    pkg_managers.yum(distro.conn, 'ceph')
+        pkg_managers.yum(distro.conn, 'ceph')
 
 
 def repo_install(distro, reponame, baseurl, gpgkey, **kw):
